# encoding: utf-8

from django.conf import settings
from django.apps import AppConfig


class SemanticUIConfig(AppConfig):
    name = 'semantic_ui'
    verbose_name = 'semantic_ui'

    def ready(self):
        super(SemanticUIConfig, self).ready()

        from semantic_ui import patch
        patch.patch_all()



# encoding: utf-8

from django.conf import settings
from crispy_forms import layout


def patch_all():
    if settings.CRISPY_TEMPLATE_PACK != 'semantic-ui':
        return

    layout.Submit.field_classes = 'ui primary button'
    layout.Button.field_classes = 'ui button'
    layout.Reset.field_classes = 'ui button'
    layout.Column.field_classes = 'column'
    layout.Field.field_classes = 'field'



#!/usr/bin/env python

from setuptools import setup, find_packages

from semantic_ui import __version__


setup(
    name='crispy-semantic-ui',
    version='.'.join(map(str, __version__)),
    description='Semantic UI template pack for crispy forms',
    url='https://github.com/alexey-grom/crispy-semantic-ui',
    author='alxgrmv@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    install_requires=['django-crispy-forms',
                      'django'],
)
